==> media_twig_tools-2.0.0-rc3.tar.gz: media_twig_tools/src/Services/OversizeChecker.php <==
<?php

namespace Drupal\media_twig_tools\Services;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\file\FileInterface;

/**
 * Service description.
 */
class OversizeChecker {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs an OversizeChecker object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Return settings without oversize rules
   *
   * @param \Drupal\file\FileInterface|NULL $file
   *   The file.
   * @param array $rules
   *   The rules.
   *
   * @return array
   *   The filtered settings.
   */
  public function getOversizeFilteredSettings(FileInterface $file = NULL, array $settings = []) {

    try {
      if (file_exists($file->getFileUri())){
        $info = getimagesize($file->getFileUri());
        if ($info){
          $dimension = array_combine(['width', 'height'], array_splice($info, 0, 2));
          foreach ($settings as $id => $rules) {
            foreach ($rules['rules'] as $rule) {
              if ($this->isRuleOversize($rule, $dimension)) {
                unset($settings[$id]);
                break;
              }
            }
          }
        }
      }
    }
    catch (\Exception $e) {
      return $settings;
    };

    return $settings;
  }

  /**
   * Check if rule is oversize.
   *
   * @param array $rule
   *   The rule data.
   * @param array $original_dimension
   *   The original dimension
   *
   * @return bool
   *   True if oversize.
   */
  public function isRuleOversize(array $rule, array $original_dimension) {
    if (isset($rule['data'])) {
      $rule_data = $rule['data'];
      $checklist = array_intersect_key($rule_data, $original_dimension);
      $oversize_dimensions = array_filter(
        $checklist,
        function ($value, $dimension) use ($original_dimension) {
          return $value > $original_dimension[$dimension];
        },
        ARRAY_FILTER_USE_BOTH
      );

      return !empty($oversize_dimensions);
    }
    return FALSE;
  }
}

==> media_twig_tools-2.1.0-rc3.tar.gz: media_twig_tools/src/Services/OversizeChecker.php <==
<?php

namespace Drupal\media_twig_tools\Services;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\file\FileInterface;

/**
 * Service description.
 */
class OversizeChecker {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * Constructs an OversizeChecker object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Return settings without oversize rules.
   *
   * @param \Drupal\file\FileInterface|null $file
   *   The file.
   * @param array $settings
   *   The settings.
   *
   * @return array
   *   The filtered settings.
   */
  public function getOversizeFilteredSettings(FileInterface $file = NULL, array $settings = []) {
    try {
      if (file_exists($file->getFileUri())) {
        $info = getimagesize($file->getFileUri());
        if ($info) {
          $dimension = array_combine(['width', 'height'], array_splice($info, 0, 2));
          foreach ($settings as $id => $rules) {
            foreach ($rules['rules'] as $rule) {
              if ($this->isRuleOversize($rule, $dimension)) {
                unset($settings[$id]);
                break;
              }
            }
          }
        }
      }
    }
    catch (\Exception $error) {
      return $settings;
    }

    return $settings;
  }

  /**
   * Check if rule is oversize.
   *
   * @param array $rule
   *   The rule data.
   * @param array $original_dimension
   *   The original dimension.
   *
   * @return bool
   *   True if oversize.
   */
  public function isRuleOversize(array $rule, array $original_dimension) {
    if (isset($rule['data'])) {
      $rule_data = $rule['data'];
      $checklist = array_intersect_key($rule_data, $original_dimension);
      $oversize_dimensions = array_filter(
        $checklist,
        function ($value, $dimension) use ($original_dimension) {
          return $value > $original_dimension[$dimension];
        },
        ARRAY_FILTER_USE_BOTH
      );

      return !empty($oversize_dimensions);
    }
    return FALSE;
  }

}
